pub struct Function {
pub name: String,
pub description: Option<String>,
pub parameters: Parameters,
pub strict: bool,
}Expand description
OpenAI API JSON 定義。 function 定義。
Fields
name: StringThe name of the function to call.
description: Option<String>A description of the function. Used by the model to determine whether or not to call the function.
parameters: ParametersA JSON schema object describing the parameters of the function.
strict: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Function
impl<'de> Deserialize<'de> for Function
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more